module Window where

import Graphics.Gloss

type Wall = (Float, Float, Float) -- (wallX - coord da parede em X, wallY - coord da parede em Y, tamanho da parede)

-- | Largura
width :: Int
width = 900

-- | Altura
height :: Int
height = 600

-- | Posição da janela
offset :: Int 
offset = 100

-- | cor do fundo
background :: Color
background = black

-- | cria a tela do jogo
window :: Display
window = InWindow "Pacman" (width, height) (offset, offset)

halfWidth :: Float
halfWidth = fromIntegral width / 2

halfHeight :: Float
halfHeight = fromIntegral height / 2

-- | Cor da borda.
wallColor :: Color
wallColor = blue

-- | bordas na horizontal
bHalfWidth :: Float -> Float
bHalfWidth x = 1 + x / 2

-- | bordas na vertical
bHalfHeight :: Float -> Float
bHalfHeight y = 1 + y / 2

-- | borda de cima e de baixo
topdownWall :: Float -> Picture
topdownWall offset = translate 0 offset
                   $ color wallColor 
                   $ rectangleSolid (fromIntegral width/1.5) 10

-- | bordas dos lados
sideWall :: Float -> Picture
sideWall offset = translate offset 0 
                $ color wallColor 
                $ rectangleSolid 5 
                $ fromIntegral height

-- | cria os retangulos na horizontal
rectanHorizontal :: Wall -> Picture
rectanHorizontal (dCenterH, dCenterV, tam) = translate dCenterH dCenterV -- distancia do centro horizontal, distancia do centro vertical 
                                       $ color wallColor 
                                       $ rectangleSolid tam 10 --sempre metade, tamanho dele

-- | cria os retangulos na vertical
rectanVertical :: Wall -> Picture
rectanVertical (dCenterH, dCenterV, tam) = translate dCenterH dCenterV 
                                     $ color wallColor 
                                     $ rectangleSolid 10 tam
                                    --  $ fromIntegral tam

-- | coordenadas dos blocos verticais
vertical :: [Wall]
vertical = [((halfWidth/2), 0, halfWidth),((-(halfWidth/2)), 0, halfWidth), (0, 180, 90),(0, (-180), 90),(135, 90, 90), (135, (-90), 90), ((-135), (-90), 90), ((-135), 90, 90)]

-- | Coordenadas dos blocos horizontais
horizontal :: [Wall]
horizontal = [(0, (halfWidth/2), (halfWidth+10)),(0, (-(halfWidth/2)), (halfWidth+10)),(0, 45, 90),(0, (-45), 90),(115, 135, 50), (115, (-135), 50), ((-115), 135, 50), ((-115), (-135), 50)]

-- | aplica a função de criar os blocos VERTICALMENTE para cada coordenada
verticalWalls :: [Picture]
verticalWalls = map rectanVertical vertical

-- | aplica a função de criar os blocos HORIZONTALMENTE para cada coordenada
horizontalWalls :: [Picture]
horizontalWalls = map rectanHorizontal horizontal

-- | Lista das paredes
wallsArray :: [Wall] 
wallsArray = concat[vertical, horizontal]

-- | forma as imagens das paredes
walls :: Picture
walls = pictures (concat[verticalWalls, horizontalWalls])

-- | Mensagem atual a ser mostrada.
curMsg :: Int -> Bool -> Picture
curMsg   0  paused = pauseMsg paused
curMsg (-1) paused = lostMsg
curMsg   1  paused = winMsg
curMsg   _  paused = text ""

-- | Mensagens de perda ou vitória
lostMsg = renderTxt red "Morreu! (r = new game)"
winMsg  = renderTxt green "Vitoria! (r = new game)"

-- | Mensagens de pausa
pauseMsg True  = renderTxt blue "Jogo pausado (aperte p)"
pauseMsg False = renderTxt blue ""
       
-- | Escreve texto na tela
renderTxt c t = translate (-250) 250 
              $ scale 0.3 1 
              $ color c 
              $ text t